@@ -56,6 +56,9 @@ IntroductionWebEnginePage::~IntroductionWebEnginePage()
 
 bool IntroductionWebEnginePage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
 {
+    if (url.scheme() == QLatin1String("data")) {
+        return true;
+    }
     Q_UNUSED(type);
     Q_UNUSED(isMainFrame);
     Q_EMIT urlClicked(url);
